==> opengate-10.0b4.tar.gz: opengate-10.0b4/opengate/tests/src/test049_pet_digit_blurring_v1.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import opengate as gate
import test049_pet_digit_blurring_helpers as t49
from opengate.tests import utility


if __name__ == "__main__":
    paths = utility.get_default_test_paths(__file__, "gate_test049_pet_blur")

    """
    see https://github.com/teaghan/PET_MonteCarlo
    and https://doi.org/10.1002/mp.16032

    PET simulation to test blurring options of the digitizer

    - PET:
    - phantom: nema necr
    - output: singles with and without various blur options
    """

    # create the simulation
    sim = gate.Simulation()
    t49.create_simulation(sim)

    # start simulation
    sim.run()

    # print results
    stats = sim.output.get_actor("Stats")
    print(stats)

    # ----------------------------------------------------------------------------------------------------------
    readout = sim.output.get_actor("Singles")
    ig = readout.GetIgnoredHitsCount()
    print()
    print(f"Nb of ignored hits : {ig}")

    # check stats
    print()
    gate.exception.warning(f"Check stats")
    p = paths.gate_output
    stats_ref = utility.read_stat_file(p / "stats.txt")
    is_ok = utility.assert_stats(stats, stats_ref, 0.025)

    # check root hits
    hc = sim.output.get_actor("Hits").user_info
    f = p / "pet.root"
    is_ok = t49.check_root_hits(paths, 1, f, hc.output, "test049_hits.png") and is_ok

    # check root singles
    sc = sim.output.get_actor("Singles").user_info
    is_ok = (
        t49.check_root_singles(paths, 1, f, sc.output, png_output="test049_singles.png")
        and is_ok
    )

    utility.test_ok(is_ok)

==> opengate-10.0.0.tar.gz: opengate-10.0.0/opengate/tests/src/test049_pet_digit_blurring_v1.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import opengate as gate
import test049_pet_digit_blurring_helpers as t49
from opengate.tests import utility


if __name__ == "__main__":
    paths = utility.get_default_test_paths(__file__, "gate_test049_pet_blur", "test049")

    """
    see https://github.com/teaghan/PET_MonteCarlo
    and https://doi.org/10.1002/mp.16032

    PET simulation to test blurring options of the digitizer

    - PET:
    - phantom: nema necr
    - output: singles with and without various blur options
    """

    # create the simulation
    sim = gate.Simulation()
    t49.create_simulation(sim, fname_suffix="_v1")

    # start simulation
    sim.run()

    # print results
    stats = sim.get_actor("Stats")
    print(stats)

    # ----------------------------------------------------------------------------------------------------------
    readout = sim.get_actor("Singles")
    ig = readout.GetIgnoredHitsCount()
    print()
    print(f"Nb of ignored hits : {ig}")

    # check stats
    print()
    gate.exception.warning(f"Check stats")
    p = paths.gate_output
    stats_ref = utility.read_stat_file(p / "stats.txt")
    is_ok = utility.assert_stats(stats, stats_ref, 0.025)

    # check root hits
    hc = sim.get_actor("Hits")
    f = p / "pet.root"
    is_ok = (
        t49.check_root_hits(paths, 1, f, hc.get_output_path(), "test049_hits.png")
        and is_ok
    )

    # check root singles
    sc = sim.get_actor("Singles")
    is_ok = (
        t49.check_root_singles(
            paths, 1, f, sc.get_output_path(), png_output="test049_singles.png"
        )
        and is_ok
    )

    utility.test_ok(is_ok)
